<template>
  <view class="page">
    <view class="finishProductIn-locno-bg" />
    <u-navbar
      title="盘点报告号"
      :background="background"
      :border-bottom="false"
      :title-bold="true"
      title-color="#000"
      back-icon-color="#000"
    />
    <view class="finishProductIn-locno-search">
      <u-search
        v-model="keywords"
        shape="square"
        bg-color="rgba(250,252,255,0.36)"
        :show-action="false"
        placeholder="请输入盘点报告号"
        @clear="search"
        @custom="search"
        @search="search"
      >
      </u-search>
    </view>
    <view class="wrap">
      <scroll-view
        class="finishProductIn-locno-scroll-list"
        scroll-y="true"
        @scrolltolower="loadMore"
      >
        <u-cell-group
          class="finishProductIn-locno-scroll-list-group"
          :border="false"
        >
          <view
            class="content"
            v-for="(item, index) in list"
            :key="item.locNo"
            :index="index"
            @click="selectNo(item.index)"
          >
            <view class="content-header">
              <view class="content-header-title">{{ item.index }}</view>
            </view>
            <view class="content-body">
              <view class="row-list">
                <view class="_label">
                  <view class="_label-icon-1"> </view>
                  <view class="_label-name">盘点报告号：</view>
                </view>
                <view class="_content">
                  {{ item.value0 }}
                </view>
              </view>
              <view class="row-list">
                <view class="_label">
                  <view class="_label-icon-2"> </view>
                  <view class="_label-name">仓库：</view>
                </view>
                <view class="_content">
                  {{ item.value1 }}
                </view>
              </view>
            </view>
          </view>
        </u-cell-group>
        <view class="loadmore" @click="loadMore">
          <u-loadmore :status="loadStatus"></u-loadmore>
        </view>
      </scroll-view>
    </view>
  </view>
</template>
<script>
import content_bg from "@/static/custom/finishProductIn/locNoBg.png";
export default {
  data() {
    return {
      background: {
        backgroundImage: `url(${content_bg})`,
        backgroundAttachment: "fixed",
        backgroundSize: "100% auto",
        backgroundRepeat: "no-repeat",
      },
      keywords: "",
      alllist: [],
      originList: [],
      query: {
        current: 1,
        size: 10,
      },
      list: [
        {
          index: 1,
          value0: "123456789",
          value1: "123456789",
        },
      ],
      count: 0,
      loadStatus: "loading",
    };
  },
  onLoad() {
    this.$u.api.finishProductIn.fetchList().then((res) => {
      this.alllist = res.data;
      this.originList = res.data;
      this.loadList();
    });
  },
  methods: {
    loadMore() {
      if (this.loadStatus == "nomore" || this.loadStatus == "loading") {
        return;
      }
      this.loadStatus = "loading";
      setTimeout(() => {
        this.query.current += 1;
        this.loadList();
      }, 100);
    },
    loadList() {
      const data = this.originList.slice(
        (this.query.current - 1) * this.query.size,
        this.query.current * this.query.size
      );
      this.list = this.list.concat(data);
      this.loadStatus = "loadmore";
      if (!data || data.length < this.query.size) {
        this.loadStatus = "nomore";
      }
    },
    search(value) {
      this.list = [];
      this.query.current = 1;
      if (value) {
        this.originList = this.alllist.filter((item) =>
          item.locNo.includes(value)
        );
      } else {
        this.originList = this.alllist;
      }
      this.loadList();
    },
    selectNo(no) {
      this.refreshLastPage(no);
    },

    //刷新上一个页面
    refreshLastPage(no) {
      // 告知 A.vue 更新数据
      // 获取页面栈
      let pages = getCurrentPages();

      // 获取上一页栈
      let prevPage = pages[pages.length - 2];

      // 触发上一页 upData 函数(并携带参数)
      prevPage.$vm.setNo({
        value1: 1896,
        value2: "铜杆",
      });

      // 返回上一页
      uni.navigateBack({
        delta: 1,
      });
    },
  },
};
</script>
<style lang="scss">
.finishProductIn-locno-bg {
  background-color: #f6f9ff;
  background-image: url("~@/static/custom/finishProductIn/locNoBg.png");
  // background: linear-gradient(180deg,rgba(206,227,254,1),rgba(206,227,254,1) 20%,rgba(206,227,254,0.5) 40%,rgba(206,227,254,0.25) 60%,rgba(206,227,254,0.08) 80%,rgba(206,227,254,0));
  padding: 0 20rpx;
  background-attachment: fixed;
  background-size: 100% auto;
  background-repeat: no-repeat;
  position: fixed;
  top: 0;
  bottom: 0;
  width: 100%;
  z-index: -1;
}

.finishProductIn-locno-search {
  padding: 40rpx 30rpx 20rpx 30rpx;
}

.wrap .finishProductIn-locno-scroll-list {
  height: calc(100vh - var(--window-top) - var(--window-bottom) - 242rpx);
  width: 100%;
}

.finishProductIn-locno-scroll-list-group {
  ::v-deep .u-cell-item-box {
    background-color: rgba(250, 252, 255, 0.36) !important;
    padding: 0rpx 30rpx;
  }

  .content {
    font-size: 12px;
    background-color: #ffffff;
    box-sizing: border-box;
    border-radius: 10rpx;
    margin: 0rpx 0rpx 16rpx;
    padding: 20rpx 8rpx;
    box-shadow: none;
    display: flex;
    align-items: center;

    .content-header {
      width: 40rpx;
      height: 90rpx;
      display: flex;
      align-items: center;

      .content-header-icon {
        background-image: url("~@/static/custom/moveWareHouse/header_icon.png");
        background-size: 100% auto;
        background-repeat: no-repeat;
        height: 28rpx;
        width: 28rpx;
      }

      .content-header-title {
        margin-left: 11rpx;
        font-size: 26rpx;
        font-weight: bold;
        color: #3d52f5;
      }
    }

    .content-body {
      flex: 1;
      background: #f5f9ff;
      border-radius: 10rpx;
      padding: 0rpx 23rpx;

      .row-list {
        height: 60rpx;
        display: flex;
        flex-direction: row;
        padding: 0px;
        align-items: center;
      }

      .row-list ._label {
        display: flex;
        flex: 0.8;
        color: #909399;
        align-items: center;

        ._label-icon-1 {
          background-image: url("~@/static/custom/moveWareHouse/label-icon-1.png");
          background-size: 100% auto;
          background-repeat: no-repeat;
          height: 26rpx;
          width: 26rpx;
        }

        ._label-icon-2 {
          background-image: url("~@/static/custom/moveWareHouse/label-icon-2.png");
          background-size: 100% auto;
          background-repeat: no-repeat;
          height: 26rpx;
          width: 26rpx;
        }

        ._label-icon-3 {
          background-image: url("~@/static/custom/moveWareHouse/label-icon-3.png");
          background-size: 100% auto;
          background-repeat: no-repeat;
          height: 26rpx;
          width: 26rpx;
        }

        ._label-name {
          margin-left: 11rpx;
          font-size: 26rpx;
          font-weight: 500;
          color: #666666;
        }
      }

      .row-list ._content {
        flex: 1.5;
        text-align: right;
        color: #909399;
        font-size: 24rpx;
      }

      .row-list .s1 {
        color: #d35651;
      }
    }
  }
}
</style>
